Reads

Struct Reads 

pub struct Reads<D> { /* private fields */ }
Store many DNA sequences together with an Exts and data each compactly packed together

fields:
  • storage: Vec with 2-bit encoded DNA bases of all sequences
  • ends: Vec with the ends (exclusive) of the separate sequences in the Reads
  • exts: Option<Vec> with one Exts for each sequence
  • data: Vec with data for each sequence
  • len: length of all sequences together
  • stranded: [Stranded] conveying the strandedness and direction of the reads

Implementations

Source

impl<D: Clone + Copy> Reads<D>

pub fn new(stranded: Strandedness) -> Self

Returns a new Reads

pub fn new_with_quality(stranded: Strandedness) -> Self

pub fn stranded(&self) -> Strandedness

pub fn n_reads(&self) -> usize

Returns the number of reads stored

pub fn mem(&self) -> usize

get the memory required for the reads

pub fn set_stranded(&mut self, stranded: Strandedness)

set the strandedness and the direction of the reads

pub fn set_custom_quality_bins(&mut self, quality_bins: QualityBins)

set custom quality bins

pub fn add_read<V: Vmer>( &mut self, seq: V, exts: Option<Exts>, data: D, quality_scores: Option<&[u8]>, )

Adds a new read to the Reads

pub fn from_vmer_vec<V: Vmer, S: IntoIterator<Item = (V, Exts, D)>>( vec_iter: S, stranded: Strandedness, ) -> Self

Transforms a [(vmer, exts, data)] into a Reads - watch for memory usage

pub fn add_from_bytes(&mut self, bytes: &[u8], exts: Option<Exts>, data: D)

add ASCII encoded bases to the Reads

will transform all ascii characters outside of ACGTacgt into A

if Reads previously contained no exts, no new exts will be added see also: Reads::add_from_bytes_checked

pub fn add_from_bytes_checked( &mut self, bytes: &[u8], exts: Option<Exts>, data: D, ) -> bool

add ASCII encoded bases to the Reads

will return false if the bytes contained characters outside of ACGTacgt, otherwise return true and add the bases see also: Reads::add_from_bytes

pub fn get_read(&self, i: usize) -> Option<Read<D>>

get the ith read in a Reads

pub fn shrink_to_fit(&mut self)

shrink the vectors’ capacity to fit the length

use sparsely

pub fn iter(&self) -> ReadsIter<'_, D>

Iterate over the reads as (DnaString, Exts, D).

pub fn partial_iter(&self, range: Range<usize>) -> ReadsIter<'_, D>

Iterate over a range start reads as (DnaString, Exts, D).

pub fn info(&self) -> String

Source

impl<D: ReadData> Reads<D>

pub fn tag_kmers(&self, k: usize) -> HashMap<Tag, usize>

get the number of k-mers for each unique data value