pub struct Reads<D> { /* private fields */ }Expand description
Store many DNA sequences together with an Exts and data each compactly packed together
fields:
storage:Vecwith 2-bit encoded DNA bases of all sequencesends:Vecwith the ends (exclusive) of the separate sequences in theReadsexts:Option<Vec>with one Exts for each sequencedata:Vecwith data for each sequencelen: length of all sequences togetherstranded: [Stranded] conveying the strandedness and direction of the reads
Implementations
Sourceimpl<D: Clone + Copy> Reads<D>
impl<D: Clone + Copy> Reads<D>
Sourcepub fn new(stranded: Strandedness) -> Self
pub fn new(stranded: Strandedness) -> Self
Returns a new Reads
pub fn new_with_quality(stranded: Strandedness) -> Self
pub fn stranded(&self) -> Strandedness
Sourcepub fn set_stranded(&mut self, stranded: Strandedness)
pub fn set_stranded(&mut self, stranded: Strandedness)
set the strandedness and the direction of the reads
Sourcepub fn set_custom_quality_bins(&mut self, quality_bins: QualityBins)
pub fn set_custom_quality_bins(&mut self, quality_bins: QualityBins)
set custom quality bins
Sourcepub fn add_read<V: Vmer>(
&mut self,
seq: V,
exts: Option<Exts>,
data: D,
quality_scores: Option<&[u8]>,
)
pub fn add_read<V: Vmer>( &mut self, seq: V, exts: Option<Exts>, data: D, quality_scores: Option<&[u8]>, )
Adds a new read to the Reads
Sourcepub fn from_vmer_vec<V: Vmer, S: IntoIterator<Item = (V, Exts, D)>>(
vec_iter: S,
stranded: Strandedness,
) -> Self
pub fn from_vmer_vec<V: Vmer, S: IntoIterator<Item = (V, Exts, D)>>( vec_iter: S, stranded: Strandedness, ) -> Self
Transforms a [(vmer, exts, data)] into a Reads - watch for memory usage
Sourcepub fn add_from_bytes(&mut self, bytes: &[u8], exts: Option<Exts>, data: D)
pub fn add_from_bytes(&mut self, bytes: &[u8], exts: Option<Exts>, data: D)
add ASCII encoded bases to the Reads
will transform all ascii characters outside of ACGTacgt into A
if Reads previously contained no exts, no new exts will be added
see also: Reads::add_from_bytes_checked
Sourcepub fn add_from_bytes_checked(
&mut self,
bytes: &[u8],
exts: Option<Exts>,
data: D,
) -> bool
pub fn add_from_bytes_checked( &mut self, bytes: &[u8], exts: Option<Exts>, data: D, ) -> bool
add ASCII encoded bases to the Reads
will return false if the bytes contained characters outside of ACGTacgt, otherwise return true and add the bases
see also: Reads::add_from_bytes
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
shrink the vectors’ capacity to fit the length
use sparsely
Sourcepub fn partial_iter(&self, range: Range<usize>) -> ReadsIter<'_, D> ⓘ
pub fn partial_iter(&self, range: Range<usize>) -> ReadsIter<'_, D> ⓘ
Iterate over a range start reads as (DnaString, Exts, D).
pub fn info(&self) -> String